/*
This file is part of the Montpellier RIO Imaging mri-base-lib package.
 
(c) 2012 CNRS
This software is developed at Montpellier RIO Imaging (IFR 122), Montpellier, France (www.mri.cnrs.fr)
Developer: Alexandre Granier (alexandre.granier@mri.cnrs.fr) 

The Montpellier RIO Imaging mri-base-lib package contains different components that
are needed in multiple projects.

This software is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms. 
*/
package fr.cnrs.mri.files;

import java.net.MalformedURLException;
import java.sql.Timestamp;

import jcifs.smb.SmbException;
import jcifs.smb.SmbFile;

/**
 * @author granier
 *
 */
public class SambaFileInformation extends GenericFileInformation {

	private SmbFile file;
	
	public SambaFileInformation(String path) {
		this.path = path;
		String smbPath = "smb:" + path;
		try {
			file = new SmbFile(smbPath);
		} catch (MalformedURLException e) {
			e.printStackTrace();
		}
	}

	@Override
	public boolean existsFile() {
		try {
			return file.exists();
		} catch (SmbException e) {
			e.printStackTrace();
		}
		return false;
	}

	@Override
	public long getSize() {
		try {
			return file.length();
		} catch (SmbException e) {
			e.printStackTrace();
		}
		return 0;
	}

	@Override
	protected void calculateModificationDate() {
		// TODO Auto-generated method stub
		
	}

	@Override
	public String getFullPath() {
		return file.getPath();
	}

	@Override
	public Timestamp getCreationDate() {
		Timestamp time = null;
		try {
			time = new Timestamp(file.createTime());
		} catch (SmbException e) {
			e.printStackTrace();
		}
		return time;
	}
}
